@@ -24,12 +24,12 @@ as.json.geo_list <- function(x, ...) to_json(unclass(x), ...)
 
 #' @export
 as.json.geojson <- function(x, ...) {
-  res <- as.SpatialPolygonsDataFrame(x, ...)
-  to_json(unclass(spdftogeolist(res)))
+  res <- as.SpatialPolygonsDataFrame(x)
+  to_json(unclass(spdftogeolist(res)), ...)
 }
 
 #' @export
 as.json.character <- function(x, ...) {
-  res <- as.SpatialPolygonsDataFrame(x, ...)
-  to_json(unclass(spdftogeolist(res)))
+  res <- as.SpatialPolygonsDataFrame(x)
+  to_json(unclass(spdftogeolist(res)), ...)
 }
